@@ -44,14 +44,12 @@ export default class LabelSegmentManager extends GraphObjectManager{
                 let queryRes=await self.ecoreSync.exec(cmd)
                 if(isConditional)
                 {
-                    if(queryRes[0])
-                    {
-                        res=prefix+format(queryRes[1],resultFormat)+suffix
-                    }                           
+                    if(queryRes[0]) res=prefix+format(queryRes[1],resultFormat)+suffix;
+                                             
                 }
                 else
                 {
-                    res=prefix+format(queryRes[0],resultFormat)+suffix
+                    if(queryRes[0]) res=prefix+format(queryRes[0],resultFormat)+suffix;                    
                 }       
             }
             catch(e)
